{% extends "request/plugins/table.html" %}
{% load i18n %}
{% block table %}
    <tr>
        <th>{% trans "Referrer" %}</th>
        <th>{% trans "Visits" %}</th>
    </tr>
    {% for referer in referrers %}
        <tr>
            <td><a href="{{ referer.referer }}" title="{{ referer.referer }}">{{ referer.referer|truncatechars:60 }}</a></td>
            <td>{{ referer.referer__count }}</td>
        </tr>
    {% endfor %}
{% endblock %}
