{% extends "request/plugins/table.html" %}
{% load i18n %}

{% block table %}
    <tr>
        <th>{% trans "User" %}</th>
    </tr>
    {% load request_tag %}
    {% active_users in 5 minutes as user_list %}
    {% for user in user_list %}
        <tr>
            <td><a href="{{ user.get_absolute_url }}">{{ user.get_username }}</a></td>
        </tr>
    {% endfor %}
{% endblock %}
