{% extends "request/plugins/table.html" %}
{% load i18n %}
{% block table %}
    <tr>
        <th>{% trans "Path" %}</th>
        <th>{% trans "From" %}</th>
        <th>{% trans "Response" %}</th>
        <th>{% trans "Time" %}</th>
    </tr>
    {% for request in requests %}
        <tr>
            <td><a href="{% url "admin:request_request_changelist" %}?path={{ request.path }}" title="{{ request.path }}">{{ request.path|truncatechars:35 }}</a></td>
            <td>{% firstof request.get_user request.ip %}</td>
            <td>{{ request.get_response_display }}</td>
            <td><a href="{% url "admin:request_request_change" request.id %}">
                <abbr class="timeago" title="{{ request.time|date:"c" }}">{{ request.time|date:"D M d H:i:s O Y" }}</abbr>
            </a></td>
        </tr>
    {% endfor %}
{% endblock %}
