# Generated by Django 2.0.2 on 2019-08-05 09:37

from django.db import migrations, models
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('request', '0006_alter_request_method_default'),
    ]

    operations = [
        migrations.AddField(
            model_name='request',
            name='get_params',
            field=models.CharField(blank=True, max_length=512, null=True),
        ),
        migrations.AddField(
            model_name='request',
            name='post_params',
            field=jsonfield.fields.JSONField(blank=True, default='{}', null=True),
        ),
    ]
