{% extends "request/plugins/table.html" %}
{% load i18n %}
{% block table %}
    <tr>
        <th>{% trans "Phrase" %}</th>
        <th>{% trans "Visits" %}</th>
    </tr>
    {% for phrase, visits in phrases %}
        <tr>
            <td>{{ phrase|truncatechars:60 }}</td>
            <td>{{ visits }}</td>
        </tr>
    {% endfor %}
{% endblock %}
