{% extends "request/plugins/table.html" %}
{% load i18n %}
{% block table %}
    <tr>
        <td>&nbsp;</td>
        <th>{% trans "Today" %}</th>
        <th>{% trans "This week" %}</th>
        <th>{% trans "This month" %}</th>
        <th>{% trans "This year" %}</th>
        <th>{% trans "Alltime" %}</th>
    </tr>
    {% for key,value in traffic %}
        <tr>
            <th>{{ key }}</th>
            {% for item in value %}
                <td>{{ item }}</td>
            {% endfor %}
        </tr>
    {% endfor %}
{% endblock %}
