__version__ = '0.0.4'
__copyright__ = 'Copyright (c) 2009-2019, Kyle Fuller, Mariusz Felisiak'
__licence__ = 'BSD'
__author__ = [
    'Kyle Fuller <kyle@fuller.li>',
    'Jannis Leidel (jezdez)',
    'krisje8 <krisje8@gmail.com>',
    'Mariusz Felisiak <felisiak.mariusz@gmail.com>',
]
__URL__ = 'https://django-request.readthedocs.io/en/latest/'
