{% extends "admin/change_list.html" %}
{% load i18n %}

{% block object-tools %}
  <ul class="object-tools">
      <li><a href="{% url "admin:request_request_overview" %}">{% trans "Overview" %}</a></li>
    {% if has_add_permission %}
      <li>
        <a href="{% url "admin:request_request_add" %}{% if is_popup %}?_popup=1{% endif %}" class="addlink">
          {% blocktrans with cl.opts.verbose_name as name %}Add {{ name }}{% endblocktrans %}
        </a>
      </li>
    {% endif %}
  </ul>
{% endblock %}
